﻿using System.IO;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.FormsEdition;
using Xamarin.Forms;

namespace GettingStarted
{
    public partial class MainPage : ContentPage
    {
        private string targetDirectory = (@"/mnt/sdcard/Android.Sample/GetStarted/");

        public MainPage()
        {
            InitializeComponent();

            MapView mapView = new MapView();
            mapView.MapUnit = GeographyUnit.Meter;

            LayerOverlay layerOverlay = new LayerOverlay();
            mapView.Overlays.Add(layerOverlay);

            Proj4Projection proj4Projection = new Proj4Projection(4326, 3857);
            proj4Projection.Open();
            TabFeatureLayer tabFeatureLayer = new TabFeatureLayer(Path.Combine(targetDirectory, "USA.TAB"), TabFileReadWriteMode.ReadOnly);
            tabFeatureLayer.FeatureSource.Projection = proj4Projection;
            tabFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Green, GeoColor.FromArgb(100, GeoColor.SimpleColors.Red));
            tabFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(tabFeatureLayer);

            TabFeatureLayer lineLayer = new TabFeatureLayer(Path.Combine(targetDirectory, "ww_line.TAB"), TabFileReadWriteMode.ReadOnly);
            lineLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Canal1;
            lineLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(lineLayer);

            TabFeatureLayer plantLayer = new TabFeatureLayer(Path.Combine(targetDirectory, "ww_plant.TAB"), TabFileReadWriteMode.ReadOnly);
            plantLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;
            plantLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(plantLayer);

            TabFeatureLayer pointLayer = new TabFeatureLayer(Path.Combine(targetDirectory, "ww_point.TAB"), TabFileReadWriteMode.ReadOnly);
            pointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;
            pointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(pointLayer);

            lineLayer.Open();
            mapView.CurrentExtent = lineLayer.GetBoundingBox();
            Content = mapView;
        }
    }
}
